package gs

import sbt._

/** Defines all setting and task keys for the GS CalVer SBT Plugin.
  */
object CalVerKeys {

  /** SBT Setting for the calculated CalVer.
    */
  lazy val calVer = settingKey[String](
    "Calculated CalVer."
  )

  /**
    * SBT setting which defines the CalVer pattern used to calculate the final
    * version. This should not be set manually, please use 
    * `calVerReleasePattern` and `calVerPreReleasePattern`.
    */
  lazy val calVerPattern = settingKey[CalVer.Pattern](
    "Selected CalVer pattern."
  )

  /**
    * User-defined SBT setting which defines the CalVer pattern to use for a
    * release build.
    */
  lazy val calVerReleasePattern = settingKey[Option[CalVer.Pattern]](
    "Pattern to use for calculating CalVer for release builds."
  )

  /**
    * User-defined SBT setting which defines the CalVer pattern to use for a
    * pre-release build.
    */
  lazy val calVerPreReleasePattern = settingKey[Option[CalVer.Pattern]](
    "Pattern to use for calculating CalVer for pre-release builds."
  )

  /** Task which emits the current version at the informational log level.
    */
  lazy val calVerInfo = taskKey[Unit](
    "Dump the calculated version information."
  )

}
