package gs

object Git {
  /**
    * Get the latest SHA. If there are no commits on this branch, the empty
    * string will be returned.
    *
    * @param length The number of characters to take from the SHA.
    * @return The latest SHA.
    */
  def getSha(length: Int): String = {
    val result = os
      .proc("git", "rev-parse", "HEAD")
      .call(
        stderr = os.ProcessOutput(
          (
            _,
            _
          ) => ()
        ),
        check = false
      )

    if (result.exitCode != 0)
      result.out.text().take(length)
    else
      ""
  }
}
